# Generated by Django 5.0.1 on 2024-03-04 05:30

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("artd_location", "0001_initial"),
        ("artd_partner", "0001_initial"),
    ]

    operations = [
        migrations.AlterField(
            model_name="coworker",
            name="dni",
            field=models.CharField(
                help_text="DNI of coworker", max_length=20, verbose_name="Dni"
            ),
        ),
        migrations.AlterField(
            model_name="coworker",
            name="first_name",
            field=models.CharField(
                help_text="First name of coworker",
                max_length=150,
                verbose_name="First name",
            ),
        ),
        migrations.AlterField(
            model_name="coworker",
            name="headquarter",
            field=models.ForeignKey(
                help_text="Headquarter of coworker",
                on_delete=django.db.models.deletion.CASCADE,
                to="artd_partner.headquarter",
                verbose_name="Headquarter",
            ),
        ),
        migrations.AlterField(
            model_name="coworker",
            name="last_name",
            field=models.CharField(
                help_text="Last name of coworker",
                max_length=150,
                verbose_name="Last name",
            ),
        ),
        migrations.AlterField(
            model_name="coworker",
            name="phone",
            field=models.CharField(
                help_text="Phone of coworker", max_length=20, verbose_name="Phone"
            ),
        ),
        migrations.AlterField(
            model_name="coworker",
            name="position",
            field=models.ForeignKey(
                help_text="Position of coworker",
                on_delete=django.db.models.deletion.CASCADE,
                to="artd_partner.position",
                verbose_name="Position",
            ),
        ),
        migrations.AlterField(
            model_name="headquarter",
            name="address",
            field=models.CharField(
                help_text="Address of headquarter",
                max_length=250,
                verbose_name="Address",
            ),
        ),
        migrations.AlterField(
            model_name="headquarter",
            name="city",
            field=models.ForeignKey(
                help_text="City of headquarter",
                on_delete=django.db.models.deletion.CASCADE,
                to="artd_location.city",
                verbose_name="City",
            ),
        ),
        migrations.AlterField(
            model_name="headquarter",
            name="name",
            field=models.CharField(
                help_text="Name of headquarter", max_length=150, verbose_name="Name"
            ),
        ),
        migrations.AlterField(
            model_name="partner",
            name="address",
            field=models.CharField(
                help_text="Address of partner", max_length=250, verbose_name="Address"
            ),
        ),
        migrations.AlterField(
            model_name="partner",
            name="city",
            field=models.ForeignKey(
                help_text="City of partner",
                on_delete=django.db.models.deletion.CASCADE,
                to="artd_location.city",
                verbose_name="City",
            ),
        ),
        migrations.AlterField(
            model_name="partner",
            name="dni",
            field=models.CharField(
                help_text="DNI of partner", max_length=20, verbose_name="Dni"
            ),
        ),
        migrations.AlterField(
            model_name="partner",
            name="email",
            field=models.EmailField(
                help_text="Email of partner", max_length=254, verbose_name="Email"
            ),
        ),
        migrations.AlterField(
            model_name="partner",
            name="name",
            field=models.CharField(
                help_text="Name of partner", max_length=150, verbose_name="Name"
            ),
        ),
        migrations.AlterField(
            model_name="partner",
            name="partner_slug",
            field=models.SlugField(
                help_text="Slug of headquarter", max_length=150, verbose_name="Slug"
            ),
        ),
        migrations.AlterField(
            model_name="position",
            name="name",
            field=models.CharField(
                help_text="Name of position", max_length=150, verbose_name="Name"
            ),
        ),
    ]
