# Generated by Django 5.0.6 on 2024-07-27 23:46

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('artd_partner', '0005_alter_coworker_created_at_alter_coworker_updated_at_and_more'),
        ('artd_service', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='partner',
            name='services',
            field=models.ManyToManyField(help_text='Services of partner', to='artd_service.service', verbose_name='Services'),
        ),
    ]
