# Generated by Django 5.0.1 on 2024-03-09 14:37

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        (
            "artd_partner",
            "0004_alter_coworker_created_at_alter_coworker_updated_at_and_more",
        ),
    ]

    operations = [
        migrations.AlterField(
            model_name="coworker",
            name="created_at",
            field=models.DateTimeField(
                auto_now_add=True, help_text="Created at", verbose_name="Created at"
            ),
        ),
        migrations.AlterField(
            model_name="coworker",
            name="updated_at",
            field=models.DateTimeField(
                auto_now=True, help_text="Updated at", verbose_name="Updated at"
            ),
        ),
        migrations.AlterField(
            model_name="headquarter",
            name="created_at",
            field=models.DateTimeField(
                auto_now_add=True, help_text="Created at", verbose_name="Created at"
            ),
        ),
        migrations.AlterField(
            model_name="headquarter",
            name="updated_at",
            field=models.DateTimeField(
                auto_now=True, help_text="Updated at", verbose_name="Updated at"
            ),
        ),
        migrations.AlterField(
            model_name="partner",
            name="created_at",
            field=models.DateTimeField(
                auto_now_add=True, help_text="Created at", verbose_name="Created at"
            ),
        ),
        migrations.AlterField(
            model_name="partner",
            name="updated_at",
            field=models.DateTimeField(
                auto_now=True, help_text="Updated at", verbose_name="Updated at"
            ),
        ),
        migrations.AlterField(
            model_name="position",
            name="created_at",
            field=models.DateTimeField(
                auto_now_add=True, help_text="Created at", verbose_name="Created at"
            ),
        ),
        migrations.AlterField(
            model_name="position",
            name="updated_at",
            field=models.DateTimeField(
                auto_now=True, help_text="Updated at", verbose_name="Updated at"
            ),
        ),
    ]
